@@ -3,13 +3,14 @@ require File.dirname(__FILE__) + '/../abstract_unit'
 class VerificationTest < Test::Unit::TestCase
   class TestController < ActionController::Base
     verify :only => :guarded_one, :params => "one",
+           :add_flash => { :error => 'unguarded' },
            :redirect_to => { :action => "unguarded" }
 
     verify :only => :guarded_two, :params => %w( one two ),
            :redirect_to => { :action => "unguarded" }
 
     verify :only => :guarded_with_flash, :params => "one",
-           :add_flash => { "notice" => "prereqs failed" },
+           :add_flash => { :notice => "prereqs failed" },
            :redirect_to => { :action => "unguarded" }
 
     verify :only => :guarded_in_session, :session => "one",
@@ -31,46 +32,53 @@ class VerificationTest < Test::Unit::TestCase
     verify :only => :two_redirects, :method => :post,
            :redirect_to => { :action => "unguarded" }
 
-    verify :only => :must_be_post, :method => :post, :render => { :status => 500, :text => "Must be post"}
+    verify :only => :must_be_post, :method => :post, :render => { :status => 405, :text => "Must be post" }, :add_headers => { "Allow" => "POST" }
+
+    verify :only => :guarded_one_for_named_route_test, :params => "one",
+           :redirect_to => :foo_url
 
     def guarded_one
-      render :text => "#{@params["one"]}"
+      render :text => "#{params[:one]}"
+    end
+    
+    def guarded_one_for_named_route_test
+      render :text => "#{params[:one]}"
     end
 
     def guarded_with_flash
-      render :text => "#{@params["one"]}"
+      render :text => "#{params[:one]}"
     end
 
     def guarded_two
-      render :text => "#{@params["one"]}:#{@params["two"]}"
+      render :text => "#{params[:one]}:#{params[:two]}"
     end
 
     def guarded_in_session
-      render :text => "#{@session["one"]}"
+      render :text => "#{session["one"]}"
     end
 
     def multi_one
-      render :text => "#{@session["one"]}:#{@session["two"]}"
+      render :text => "#{session["one"]}:#{session["two"]}"
     end
 
     def multi_two
-      render :text => "#{@session["two"]}:#{@session["one"]}"
+      render :text => "#{session["two"]}:#{session["one"]}"
     end
 
     def guarded_by_method
-      render :text => "#{@request.method}"
+      render :text => "#{request.method}"
     end
     
     def guarded_by_xhr
-      render :text => "#{@request.xhr?}"
+      render :text => "#{request.xhr?}"
     end
     
     def guarded_by_not_xhr
-      render :text => "#{@request.xhr?}"
+      render :text => "#{request.xhr?}"
     end
 
     def unguarded
-      render :text => "#{@params["one"]}"
+      render :text => "#{params[:one]}"
     end
 
     def two_redirects
@@ -93,6 +101,14 @@ class VerificationTest < Test::Unit::TestCase
     @controller = TestController.new
     @request    = ActionController::TestRequest.new
     @response   = ActionController::TestResponse.new
+    ActionController::Routing::Routes.add_named_route :foo, '/foo', :controller => 'test', :action => 'foo'
+  end
+  
+  def test_no_deprecation_warning_for_named_route
+    assert_not_deprecated do
+      get :guarded_one_for_named_route_test, :two => "not one"
+      assert_redirected_to '/foo'
+    end
   end
 
   def test_guarded_one_with_prereqs
@@ -103,18 +119,19 @@ class VerificationTest < Test::Unit::TestCase
   def test_guarded_one_without_prereqs
     get :guarded_one
     assert_redirected_to :action => "unguarded"
+    assert_equal 'unguarded', flash[:error]
   end
 
   def test_guarded_with_flash_with_prereqs
     get :guarded_with_flash, :one => "here"
     assert_equal "here", @response.body
-    assert_flash_empty
+    assert flash.empty?
   end
 
   def test_guarded_with_flash_without_prereqs
     get :guarded_with_flash
     assert_redirected_to :action => "unguarded"
-    assert_flash_equal "prereqs failed", "notice"
+    assert_equal "prereqs failed", flash[:notice]
   end
 
   def test_guarded_two_with_prereqs
@@ -212,13 +229,13 @@ class VerificationTest < Test::Unit::TestCase
     assert_equal "Was a post!", @response.body
   end
     
-  def test_guarded_post_and_calls_render_fails
+  def test_guarded_post_and_calls_render_fails_and_sets_allow_header
     get :must_be_post
-    assert_response 500
+    assert_response 405
     assert_equal "Must be post", @response.body
+    assert_equal "POST", @response.headers["Allow"]
   end
   
-
   def test_second_redirect
     assert_nothing_raised { get :two_redirects }
   end
