@@ -1,9 +1,11 @@
 DROP TABLE accounts;
+DROP TABLE funny_jokes;
 DROP TABLE companies;
 DROP TABLE topics;
 DROP TABLE developers;
 DROP TABLE projects;
 DROP TABLE developers_projects;
+DROP TABLE orders;
 DROP TABLE customers;
 DROP TABLE movies;
 DROP TABLE subscribers;
@@ -13,6 +15,7 @@ DROP TABLE entrants;
 DROP TABLE colnametests;
 DROP TABLE mixins;
 DROP TABLE people;
+DROP TABLE readers;
 DROP TABLE binaries;
 DROP TABLE computers;
 DROP TABLE posts;
@@ -21,4 +24,9 @@ DROP TABLE authors;
 DROP TABLE tasks;
 DROP TABLE categories;
 DROP TABLE categories_posts;
-
+DROP TABLE fk_test_has_pk;
+DROP TABLE fk_test_has_fk;
+DROP TABLE keyboards;
+DROP TABLE legacy_things;
+DROP TABLE numeric_data;
+DROP TABLE mixed_case_monkeys;
