@@ -1,10 +1,14 @@
 DROP TABLE accounts;
+DROP SEQUENCE accounts_id_seq;
+DROP TABLE funny_jokes;
 DROP TABLE companies;
+DROP SEQUENCE companies_nonstd_seq;
 DROP TABLE topics;
 DROP TABLE developers;
 DROP TABLE projects;
 DROP TABLE developers_projects;
 DROP TABLE customers;
+DROP TABLE orders;
 DROP TABLE movies;
 DROP TABLE subscribers;
 DROP TABLE booleantests;
@@ -13,6 +17,7 @@ DROP TABLE entrants;
 DROP TABLE colnametests;
 DROP TABLE mixins;
 DROP TABLE people;
+DROP TABLE readers;
 DROP TABLE binaries;
 DROP TABLE computers;
 DROP TABLE posts;
@@ -24,3 +29,9 @@ DROP TABLE categories_posts;
 DROP TABLE defaults;
 DROP TABLE fk_test_has_fk;
 DROP TABLE fk_test_has_pk;
+DROP TABLE geometrics;
+DROP TABLE keyboards;
+DROP TABLE legacy_things;
+DROP TABLE numeric_data;
+DROP TABLE column_data;
+DROP TABLE mixed_case_monkeys;
