@@ -26,16 +26,16 @@ class ValidationsTest < Test::Unit::TestCase
   def test_single_field_validation
     r = Reply.new
     r.title = "There's no content!"
-    assert !r.save, "A reply without content shouldn't be saveable"
+    assert !r.valid?, "A reply without content shouldn't be saveable"
 
     r.content = "Messa content!"
-    assert r.save, "A reply with content should be saveable"
+    assert r.valid?, "A reply with content should be saveable"
   end
 
   def test_single_attr_validation_and_error_msg
     r = Reply.new
     r.title = "There's no content!"
-    r.save
+    assert !r.valid?
     assert r.errors.invalid?("content"), "A reply without content should mark that attribute as invalid"
     assert_equal "Empty", r.errors.on("content"), "A reply without content should contain an error"
     assert_equal 1, r.errors.count
@@ -43,7 +43,7 @@ class ValidationsTest < Test::Unit::TestCase
 
   def test_double_attr_validation_and_error_msg
     r = Reply.new
-    assert !r.save
+    assert !r.valid?
 
     assert r.errors.invalid?("title"), "A reply without title should mark that attribute as invalid"
     assert_equal "Empty", r.errors.on("title"), "A reply without title should contain an error"
@@ -57,7 +57,7 @@ class ValidationsTest < Test::Unit::TestCase
   def test_error_on_create
     r = Reply.new
     r.title = "Wrong Create"
-    assert !r.save
+    assert !r.valid?
     assert r.errors.invalid?("title"), "A reply with a bad title should mark that attribute as invalid"
     assert_equal "is Wrong Create", r.errors.on("title"), "A reply with a bad content should contain an error"
   end
@@ -76,8 +76,22 @@ class ValidationsTest < Test::Unit::TestCase
   end
 
   def test_invalid_record_exception
-    r = Reply.new
-    assert_raises(ActiveRecord::RecordInvalid) { r.save! }
+    assert_raises(ActiveRecord::RecordInvalid) { Reply.create! }
+    assert_raises(ActiveRecord::RecordInvalid) { Reply.new.save! }
+
+    begin
+      r = Reply.new
+      r.save!
+      flunk
+    rescue ActiveRecord::RecordInvalid => invalid
+      assert_equal r, invalid.record
+    end
+  end
+
+  def test_scoped_create_without_attributes
+    Reply.with_scope(:create => {}) do
+      assert_raises(ActiveRecord::RecordInvalid) { Reply.create! }
+    end
   end
 
   def test_single_error_per_attr_iteration
@@ -127,6 +141,12 @@ class ValidationsTest < Test::Unit::TestCase
     assert reply.save(false)
   end
 
+  def test_create_without_validation_bang
+    count = Reply.count
+    assert_nothing_raised { Reply.new.save_without_validation! }
+    assert count+1, Reply.count
+  end
+
   def test_validates_each
     perform = true
     hits = 0
@@ -145,24 +165,21 @@ class ValidationsTest < Test::Unit::TestCase
     perform = false
   end
 
-  def test_errors_on_boundary_breaking
-    developer = Developer.new("name" => "xs")
-    assert !developer.save
-    assert_equal "is too short (min is 3 characters)", developer.errors.on("name")
-
-    developer.name = "All too very long for this boundary, it really is"
-    assert !developer.save
-    assert_equal "is too long (max is 20 characters)", developer.errors.on("name")
-
-    developer.name = "Just right"
-    assert developer.save
-  end
-
-  def test_title_confirmation_no_confirm
+  def test_no_title_confirmation
     Topic.validates_confirmation_of(:title)
 
-    t = Topic.create("title" => "We should not be confirmed")
-    assert t.save
+    t = Topic.new(:author_name => "Plutarch")
+    assert t.valid?
+
+    t.title_confirmation = "Parallel Lives"
+    assert !t.valid?
+
+    t.title_confirmation = nil
+    t.title = "Parallel Lives"
+    assert t.valid?
+
+    t.title_confirmation = "Parallel Lives"
+    assert t.valid?
   end
 
   def test_title_confirmation
@@ -272,6 +289,61 @@ class ValidationsTest < Test::Unit::TestCase
     assert r3.valid?, "Saving r3"
   end
 
+  def test_validate_uniqueness_with_scope_array
+    Reply.validates_uniqueness_of(:author_name, :scope => [:author_email_address, :parent_id])
+
+    t = Topic.create("title" => "The earth is actually flat!")
+ 
+    r1 = t.replies.create "author_name" => "jeremy", "author_email_address" => "jeremy@rubyonrails.com", "title" => "You're crazy!", "content" => "Crazy reply"
+    assert r1.valid?, "Saving r1"
+    
+    r2 = t.replies.create "author_name" => "jeremy", "author_email_address" => "jeremy@rubyonrails.com", "title" => "You're crazy!", "content" => "Crazy reply again..."
+    assert !r2.valid?, "Saving r2. Double reply by same author." 
+    
+    r2.author_email_address = "jeremy_alt_email@rubyonrails.com"
+    assert r2.save, "Saving r2 the second time." 
+    
+    r3 = t.replies.create "author_name" => "jeremy", "author_email_address" => "jeremy_alt_email@rubyonrails.com", "title" => "You're wrong", "content" => "It's cubic"
+    assert !r3.valid?, "Saving r3"
+    
+    r3.author_name = "jj"
+    assert r3.save, "Saving r3 the second time."
+    
+    r3.author_name = "jeremy"
+    assert !r3.save, "Saving r3 the third time."
+  end
+
+  def test_validate_case_insensitive_uniqueness
+    Topic.validates_uniqueness_of(:title, :parent_id, :case_sensitive => false, :allow_nil => true)
+
+    t = Topic.new("title" => "I'm unique!", :parent_id => 2)
+    assert t.save, "Should save t as unique"
+
+    t.content = "Remaining unique"
+    assert t.save, "Should still save t as unique"
+
+    t2 = Topic.new("title" => "I'm UNIQUE!", :parent_id => 1)
+    assert !t2.valid?, "Shouldn't be valid"
+    assert !t2.save, "Shouldn't save t2 as unique"
+    assert t2.errors.on(:title)
+    assert t2.errors.on(:parent_id)
+    assert_equal "has already been taken", t2.errors.on(:title)
+
+    t2.title = "I'm truly UNIQUE!"
+    assert !t2.valid?, "Shouldn't be valid"
+    assert !t2.save, "Shouldn't save t2 as unique"
+    assert_nil t2.errors.on(:title)
+    assert t2.errors.on(:parent_id)
+
+    t2.parent_id = 3
+    assert t2.save, "Should now save t2 as unique"
+
+    t2.parent_id = nil
+    t2.title = nil
+    assert t2.valid?, "should validate with nil"
+    assert t2.save, "should save with nil"
+  end
+
   def test_validate_format
     Topic.validates_format_of(:title, :content, :with => /^Validation\smacros \w+!$/, :message => "is bad data")
 
@@ -288,6 +360,34 @@ class ValidationsTest < Test::Unit::TestCase
 
     assert_raise(ArgumentError) { Topic.validates_format_of(:title, :content) }
   end
+  
+  # testing ticket #3142
+  def test_validate_format_numeric
+    Topic.validates_format_of(:title, :content, :with => /^[1-9][0-9]*$/, :message => "is bad data")
+
+    t = Topic.create("title" => "72x", "content" => "6789")
+    assert !t.valid?, "Shouldn't be valid"
+    assert !t.save, "Shouldn't save because it's invalid"
+    assert_equal "is bad data", t.errors.on(:title)
+    assert_nil t.errors.on(:content)
+
+    t.title = "-11"
+    assert !t.valid?, "Shouldn't be valid"
+
+    t.title = "03"
+    assert !t.valid?, "Shouldn't be valid"
+
+    t.title = "z44"
+    assert !t.valid?, "Shouldn't be valid"
+
+    t.title = "5v7"
+    assert !t.valid?, "Shouldn't be valid"
+
+    t.title = "1"
+
+    assert t.save
+    assert_nil t.errors.on(:title)
+  end
 
   def test_validates_inclusion_of
     Topic.validates_inclusion_of( :title, :in => %w( a b c d e f g ) )
@@ -342,17 +442,17 @@ class ValidationsTest < Test::Unit::TestCase
     t.title = "not"
     assert !t.valid?
     assert t.errors.on(:title)
-    assert_equal "is too short (min is 5 characters)", t.errors["title"]
+    assert_equal "is too short (minimum is 5 characters)", t.errors["title"]
 
     t.title = ""
     assert !t.valid?
     assert t.errors.on(:title)
-    assert_equal "is too short (min is 5 characters)", t.errors["title"]
+    assert_equal "is too short (minimum is 5 characters)", t.errors["title"]
 
     t.title = nil
     assert !t.valid?
     assert t.errors.on(:title)
-    assert_equal "is too short (min is 5 characters)", t.errors["title"]
+    assert_equal "is too short (minimum is 5 characters)", t.errors["title"]
   end
 
   def test_optionally_validates_length_of_using_minimum
@@ -374,7 +474,7 @@ class ValidationsTest < Test::Unit::TestCase
     t.title = "notvalid"
     assert !t.valid?
     assert t.errors.on(:title)
-    assert_equal "is too long (max is 5 characters)", t.errors["title"]
+    assert_equal "is too long (maximum is 5 characters)", t.errors["title"]
 
     t.title = ""
     assert t.valid?
@@ -396,15 +496,20 @@ class ValidationsTest < Test::Unit::TestCase
   def test_validates_length_of_using_within
     Topic.validates_length_of(:title, :content, :within => 3..5)
 
-    t = Topic.create("title" => "a!", "content" => "I'm ooooooooh so very long")
-    assert !t.save
+    t = Topic.new("title" => "a!", "content" => "I'm ooooooooh so very long")
+    assert !t.valid?
+    assert_equal "is too short (minimum is 3 characters)", t.errors.on(:title)
+    assert_equal "is too long (maximum is 5 characters)", t.errors.on(:content)
 
-    assert_equal "is too short (min is 3 characters)", t.errors.on(:title)
-    assert_equal "is too long (max is 5 characters)", t.errors.on(:content)
+    t.title = nil
+    t.content = nil
+    assert !t.valid?
+    assert_equal "is too short (minimum is 3 characters)", t.errors.on(:title)
+    assert_equal "is too short (minimum is 3 characters)", t.errors.on(:content)
 
     t.title = "abe"
     t.content  = "mad"
-    assert t.save
+    assert t.valid?
   end
 
   def test_optionally_validates_length_of_using_within
@@ -508,6 +613,18 @@ class ValidationsTest < Test::Unit::TestCase
 
     assert_equal 'tu est trops petit hombre 10', t.errors['title']
   end
+  
+  def test_add_on_boundary_breaking_is_deprecated
+    t = Topic.new('title' => 'noreplies', 'content' => 'whatever')
+    class << t
+      def validate
+        errors.add_on_boundary_breaking('title', 1..6)
+      end
+    end
+    assert_deprecated 'add_on_boundary_breaking' do
+      assert !t.valid?
+    end
+  end
 
   def test_validates_size_of_association
     assert_nothing_raised { Topic.validates_size_of :replies, :minimum => 1 }
@@ -577,6 +694,141 @@ class ValidationsTest < Test::Unit::TestCase
     assert_equal "hoo 5", t.errors["title"]
   end
 
+  def kcode_scope(kcode)
+    orig_kcode = $KCODE
+    $KCODE = kcode
+    begin
+      yield
+    ensure
+      $KCODE = orig_kcode
+    end
+  end
+
+  def test_validates_length_of_using_minimum_utf8
+    kcode_scope('UTF8') do
+      Topic.validates_length_of :title, :minimum => 5
+
+      t = Topic.create("title" => "一二三四五", "content" => "whatever")
+      assert t.valid?
+
+      t.title = "一二三四"
+      assert !t.valid?
+      assert t.errors.on(:title)
+      assert_equal "is too short (minimum is 5 characters)", t.errors["title"]
+    end
+  end
+
+  def test_validates_length_of_using_maximum_utf8
+    kcode_scope('UTF8') do
+      Topic.validates_length_of :title, :maximum => 5
+
+      t = Topic.create("title" => "一二三四五", "content" => "whatever")
+      assert t.valid?
+
+      t.title = "一二34五六"
+      assert !t.valid?
+      assert t.errors.on(:title)
+      assert_equal "is too long (maximum is 5 characters)", t.errors["title"]
+    end
+  end
+
+  def test_validates_length_of_using_within_utf8
+    kcode_scope('UTF8') do
+      Topic.validates_length_of(:title, :content, :within => 3..5)
+
+      t = Topic.new("title" => "一二", "content" => "12三四五六七")
+      assert !t.valid?
+      assert_equal "is too short (minimum is 3 characters)", t.errors.on(:title)
+      assert_equal "is too long (maximum is 5 characters)", t.errors.on(:content)
+      t.title = "一二三"
+      t.content  = "12三"
+      assert t.valid?
+    end
+  end
+
+  def test_optionally_validates_length_of_using_within_utf8
+    kcode_scope('UTF8') do
+      Topic.validates_length_of :title, :content, :within => 3..5, :allow_nil => true
+
+      t = Topic.create('title' => '一二三', 'content' => '一二三四五')
+      assert t.valid?
+
+      t.title = nil
+      assert t.valid?
+    end
+  end
+
+  def test_optionally_validates_length_of_using_within_on_create_utf8
+    kcode_scope('UTF8') do
+      Topic.validates_length_of :title, :content, :within => 5..10, :on => :create, :too_long => "長すぎます: %d"
+
+      t = Topic.create("title" => "一二三四五六七八九十A", "content" => "whatever")
+      assert !t.save
+      assert t.errors.on(:title)
+      assert_equal "長すぎます: 10", t.errors[:title]
+
+      t.title = "一二三四五六七八九"
+      assert t.save
+
+      t.title = "一二3"
+      assert t.save
+
+      t.content = "一二三四五六七八九十"
+      assert t.save
+
+      t.content = t.title = "一二三四五六"
+      assert t.save
+    end
+  end
+
+  def test_optionally_validates_length_of_using_within_on_update_utf8
+    kcode_scope('UTF8') do    
+      Topic.validates_length_of :title, :content, :within => 5..10, :on => :update, :too_short => "短すぎます: %d"
+
+      t = Topic.create("title" => "一二三4", "content" => "whatever")
+      assert !t.save
+      assert t.errors.on(:title)
+
+      t.title = "1二三4"
+      assert !t.save
+      assert t.errors.on(:title)
+      assert_equal "短すぎます: 5", t.errors[:title]
+
+      t.title = "valid"
+      t.content = "一二三四五六七八九十A"
+      assert !t.save
+      assert t.errors.on(:content)
+
+      t.content = "一二345"
+      assert t.save
+    end
+  end
+
+  def test_validates_length_of_using_is_utf8
+    kcode_scope('UTF8') do
+      Topic.validates_length_of :title, :is => 5
+
+      t = Topic.create("title" => "一二345", "content" => "whatever")
+      assert t.valid?
+
+      t.title = "一二345六"
+      assert !t.valid?
+      assert t.errors.on(:title)
+      assert_equal "is the wrong length (should be 5 characters)", t.errors["title"]
+    end
+  end
+
+  def test_validates_size_of_association_utf8
+    kcode_scope('UTF8') do
+      assert_nothing_raised { Topic.validates_size_of :replies, :minimum => 1 }
+      t = Topic.new('title' => 'あいうえお', 'content' => 'かきくけこ')
+      assert !t.save
+      assert t.errors.on(:replies)
+      t.replies.create('title' => 'あいうえお', 'content' => 'かきくけこ')
+      assert t.valid?
+    end
+  end
+
   def test_validates_associated_many
     Topic.validates_associated( :replies )
     t = Topic.create("title" => "uhohuhoh", "content" => "whatever")
@@ -614,7 +866,7 @@ class ValidationsTest < Test::Unit::TestCase
   end
 
   def test_throw_away_typing
-    d = Developer.create "name" => "David", "salary" => "100,000"
+    d = Developer.new("name" => "David", "salary" => "100,000")
     assert !d.valid?
     assert_equal 100, d.salary
     assert_equal "100,000", d.salary_before_type_cast
@@ -629,20 +881,20 @@ class ValidationsTest < Test::Unit::TestCase
   end
 
   def test_validates_confirmation_of_with_custom_error_using_quotes
-    Developer.validates_confirmation_of :name, :message=> "This string contains 'single' and \"double\" quotes"
+    Developer.validates_confirmation_of :name, :message=> "confirm 'single' and \"double\" quotes"
     d = Developer.new
     d.name = "John"
     d.name_confirmation = "Johnny"
     assert !d.valid?
-    assert_equal d.errors.on(:name), "This string contains 'single' and \"double\" quotes"
+    assert_equal "confirm 'single' and \"double\" quotes", d.errors.on(:name)
   end
 
   def test_validates_format_of_with_custom_error_using_quotes
-    Developer.validates_format_of :name, :with => /^(A-Z*)$/, :message=> "This string contains 'single' and \"double\" quotes"
+    Developer.validates_format_of :name, :with => /^(A-Z*)$/, :message=> "format 'single' and \"double\" quotes"
     d = Developer.new
-    d.name = "John 32"
+    d.name = d.name_confirmation = "John 32"
     assert !d.valid?
-    assert_equal d.errors.on(:name), "This string contains 'single' and \"double\" quotes"
+    assert_equal "format 'single' and \"double\" quotes", d.errors.on(:name)
   end
 
   def test_validates_inclusion_of_with_custom_error_using_quotes
@@ -650,7 +902,7 @@ class ValidationsTest < Test::Unit::TestCase
     d = Developer.new
     d.salary = "90,000"
     assert !d.valid?
-    assert_equal d.errors.on(:salary).first, "This string contains 'single' and \"double\" quotes"
+    assert_equal "This string contains 'single' and \"double\" quotes", d.errors.on(:salary).first
   end
 
   def test_validates_length_of_with_custom_too_long_using_quotes
@@ -658,7 +910,7 @@ class ValidationsTest < Test::Unit::TestCase
     d = Developer.new
     d.name = "Jeffrey"
     assert !d.valid?
-    assert_equal d.errors.on(:name).first, "This string contains 'single' and \"double\" quotes"
+    assert_equal "This string contains 'single' and \"double\" quotes", d.errors.on(:name).first
   end
 
   def test_validates_length_of_with_custom_too_short_using_quotes
@@ -666,7 +918,7 @@ class ValidationsTest < Test::Unit::TestCase
     d = Developer.new
     d.name = "Joe"
     assert !d.valid?
-    assert_equal d.errors.on(:name).first, "This string contains 'single' and \"double\" quotes"
+    assert_equal "This string contains 'single' and \"double\" quotes", d.errors.on(:name).first
   end
 
   def test_validates_length_of_with_custom_message_using_quotes
@@ -674,7 +926,7 @@ class ValidationsTest < Test::Unit::TestCase
     d = Developer.new
     d.name = "Joe"
     assert !d.valid?
-    assert_equal d.errors.on(:name).first, "This string contains 'single' and \"double\" quotes"
+    assert_equal "This string contains 'single' and \"double\" quotes", d.errors.on(:name).first
   end
 
   def test_validates_presence_of_with_custom_message_using_quotes
@@ -682,7 +934,7 @@ class ValidationsTest < Test::Unit::TestCase
     d = Developer.new
     d.name = "Joe"
     assert !d.valid?
-    assert_equal d.errors.on(:non_existent), "This string contains 'single' and \"double\" quotes"
+    assert_equal "This string contains 'single' and \"double\" quotes", d.errors.on(:non_existent)
   end
 
   def test_validates_uniqueness_of_with_custom_message_using_quotes
@@ -690,7 +942,7 @@ class ValidationsTest < Test::Unit::TestCase
     d = Developer.new
     d.name = "David"
     assert !d.valid?
-    assert_equal d.errors.on(:name).first, "This string contains 'single' and \"double\" quotes"
+    assert_equal "This string contains 'single' and \"double\" quotes", d.errors.on(:name).first
   end
 
   def test_validates_associated_with_custom_message_using_quotes
@@ -699,44 +951,7 @@ class ValidationsTest < Test::Unit::TestCase
     r = Reply.create("title" => "A reply", "content" => "with content!")
     r.topic = Topic.create("title" => "uhohuhoh")
     assert !r.valid?
-    assert_equal r.errors.on(:topic).first, "This string contains 'single' and \"double\" quotes"
-  end
-
-  def test_validates_numericality_of_with_string
-    Topic.validates_numericality_of( :approved )
-    ["not a number","42 not a number","0xdeadbeef","00-1","-+019.0","12.12.13.12",nil].each do |v|
-        t = Topic.create("title" => "numeric test", "content" => "whatever", "approved" => "not a number")
-        assert !t.valid?, "#{v} not rejected as a number"
-        assert t.errors.on(:approved)
-    end
-  end
-
-  def test_validates_numericality_of
-    Topic.validates_numericality_of( :approved, :allow_nil => true )
-    ["10", "10.0", "10.5", "-10.5", "-0.0001","0090","-090","-090.1",nil,""].each do |v|
-        t = Topic.new("title" => "numeric test", "content" => "whatever", "approved" => v)
-        assert t.valid?, "#{v} not recognized as a number"
-        # we cannot check this as approved is actually an integer field
-        #assert_in_delta v.to_f, t.approved, 0.0000001
-    end
-  end
-
-  def test_validates_numericality_of_int_with_string
-    Topic.validates_numericality_of( :approved, :only_integer => true )
-    ["not a number","42 not a number","0xdeadbeef","0-1","--3","+-3","+3-1",nil].each do |v|
-        t = Topic.create("title" => "numeric test", "content" => "whatever", "approved" => v)
-        assert !t.valid?, "#{v} not rejected as integer"
-        assert t.errors.on(:approved)
-    end
-  end
-
-  def test_validates_numericality_of_int
-    Topic.validates_numericality_of( :approved, :only_integer => true, :allow_nil => true )
-    ["42", "+42", "-42", "042", "0042", "-042", 42, nil,""].each do |v|
-        t = Topic.new("title" => "numeric test", "content" => "whatever", "approved" => v)
-        assert t.valid?, "#{v} not recognized as integer"
-        assert_equal((v.nil? or v == "")? nil : v.to_i, t.approved)
-    end
+    assert_equal "This string contains 'single' and \"double\" quotes", r.errors.on(:topic).first
   end
 
   def test_conditional_validation_using_method_true
@@ -753,7 +968,7 @@ class ValidationsTest < Test::Unit::TestCase
     Topic.validates_length_of( :title, :maximum=>5, :too_long=>"hoo %d", :if => :condition_is_true_but_its_not )
     t = Topic.create("title" => "uhohuhoh", "content" => "whatever")
     assert t.valid?
-    assert !t.errors.on(:title)      
+    assert !t.errors.on(:title)
   end
 
   def test_conditional_validation_using_string_true
@@ -801,4 +1016,82 @@ class ValidationsTest < Test::Unit::TestCase
     r.topic = Topic.find :first
     assert r.valid?
   end
-end
\ No newline at end of file
+
+  def test_errors_to_xml
+    r = Reply.new :title => "Wrong Create"
+    assert !r.valid?
+    xml = r.errors.to_xml(:skip_instruct => true)
+    assert_equal "<errors>", xml.first(8)
+    assert xml.include?("<error>Title is Wrong Create</error>")
+    assert xml.include?("<error>Content Empty</error>")
+  end
+end
+
+
+class ValidatesNumericalityTest < Test::Unit::TestCase
+  NIL = [nil]
+  BLANK = ["", " ", " \t \r \n"]
+  BIGDECIMAL_STRINGS = %w(12345678901234567890.1234567890) # 30 significent digits
+  FLOAT_STRINGS = %w(0.0 +0.0 -0.0 10.0 10.5 -10.5 -0.0001 -090.1 90.1e1 -90.1e5 -90.1e-5 90e-5)
+  INTEGER_STRINGS = %w(0 +0 -0 10 +10 -10 0090 -090)
+  FLOATS = [0.0, 10.0, 10.5, -10.5, -0.0001] + FLOAT_STRINGS
+  INTEGERS = [0, 10, -10] + INTEGER_STRINGS
+  BIGDECIMAL = BIGDECIMAL_STRINGS.collect! { |bd| BigDecimal.new(bd) }
+  JUNK = ["not a number", "42 not a number", "0xdeadbeef", "00-1", "--3", "+-3", "+3-1", "-+019.0", "12.12.13.12", "123\nnot a number"]
+
+  def setup
+    Topic.write_inheritable_attribute(:validate, nil)
+    Topic.write_inheritable_attribute(:validate_on_create, nil)
+    Topic.write_inheritable_attribute(:validate_on_update, nil)
+  end
+
+  def test_default_validates_numericality_of
+    Topic.validates_numericality_of :approved
+
+    invalid!(NIL + BLANK + JUNK)
+    valid!(FLOATS + INTEGERS + BIGDECIMAL)
+  end
+
+  def test_validates_numericality_of_with_nil_allowed
+    Topic.validates_numericality_of :approved, :allow_nil => true
+
+    invalid!(BLANK + JUNK)
+    valid!(NIL + FLOATS + INTEGERS + BIGDECIMAL)
+  end
+
+  def test_validates_numericality_of_with_integer_only
+    Topic.validates_numericality_of :approved, :only_integer => true
+
+    invalid!(NIL + BLANK + JUNK + FLOATS + BIGDECIMAL)
+    valid!(INTEGERS)
+  end
+
+  def test_validates_numericality_of_with_integer_only_and_nil_allowed
+    Topic.validates_numericality_of :approved, :only_integer => true, :allow_nil => true
+
+    invalid!(BLANK + JUNK + FLOATS + BIGDECIMAL)
+    valid!(NIL + INTEGERS)
+  end
+
+  private
+    def invalid!(values)
+      with_each_topic_approved_value(values) do |topic, value|
+        assert !topic.valid?, "#{value.inspect} not rejected as a number"
+        assert topic.errors.on(:approved)
+      end
+    end
+
+    def valid!(values)
+      with_each_topic_approved_value(values) do |topic, value|
+        assert topic.valid?, "#{value.inspect} not accepted as a number"
+      end
+    end
+
+    def with_each_topic_approved_value(values)
+      topic = Topic.new("title" => "numeric test", "content" => "whatever")
+      values.each do |value|
+        topic.approved = value
+        yield topic, value
+      end
+    end
+end
