@@ -1,6 +1,3 @@
-require 'date'
-require 'time'
-
 module ActiveSupport #:nodoc:
   module CoreExtensions #:nodoc:
     module Time #:nodoc:
@@ -13,8 +10,7 @@ module ActiveSupport #:nodoc:
           :rfc822 => "%a, %d %b %Y %H:%M:%S %z"
         }
 
-        def self.append_features(klass)
-          super
+        def self.included(klass)
           klass.send(:alias_method, :to_default_s, :to_s)
           klass.send(:alias_method, :to_s, :to_formatted_s)
         end
