@@ -1,5 +1,4 @@
-require 'test/unit'
-require File.dirname(__FILE__) + '/../lib/active_support/inflector' unless defined? Inflector
+require File.dirname(__FILE__) + '/abstract_unit'
 
 module Ace
   module Base
@@ -63,47 +62,47 @@ class InflectorTest < Test::Unit::TestCase
 
     "old_news"    => "old_news",
     "news"        => "news",
-    
+
     "series"      => "series",
     "species"     => "species",
 
     "quiz"        => "quizzes",
 
     "perspective" => "perspectives",
-    
-    "ox" => "oxen",
-    "photo" => "photos",
-    "buffalo" => "buffaloes",
-    "tomato" => "tomatoes",
-    "dwarf" => "dwarves",
-    "elf" => "elves",
-    "information" => "information",
-    "equipment" => "equipment",
-    "bus" => "buses", 
-    "status" => "statuses",
-    "status_code" => "status_codes",
-    "mouse" => "mice",
 
-    "louse" => "lice",
-    "house" => "houses",
-    "octopus" => "octopi",
-    "virus" => "viri",
-    "alias" => "aliases",
-    "portfolio" => "portfolios",
-    
-    "vertex" => "vertices",
-    "matrix" => "matrices",
-    
-    "axis" => "axes",
-    "testis" => "testes",
-    "crisis" => "crises",
-    
-    "rice" => "rice",
-    "shoe" => "shoes",
-    
-    "horse" => "horses",
-    "prize" => "prizes",
-    "edge" => "edges"
+    "ox"          => "oxen",
+    "photo"       => "photos",
+    "buffalo"     => "buffaloes",
+    "tomato"      => "tomatoes",
+    "dwarf"       => "dwarves",
+    "elf"         => "elves",
+    "information" => "information",
+    "equipment"   => "equipment",
+    "bus"         => "buses",
+    "status"      => "statuses",
+    "status_code" => "status_codes",
+    "mouse"       => "mice",
+
+    "louse"       => "lice",
+    "house"       => "houses",
+    "octopus"     => "octopi",
+    "virus"       => "viri",
+    "alias"       => "aliases",
+    "portfolio"   => "portfolios",
+
+    "vertex"      => "vertices",
+    "matrix"      => "matrices",
+
+    "axis"        => "axes",
+    "testis"      => "testes",
+    "crisis"      => "crises",
+
+    "rice"        => "rice",
+    "shoe"        => "shoes",
+
+    "horse"       => "horses",
+    "prize"       => "prizes",
+    "edge"        => "edges"
   }
 
   CamelToUnderscore = {
@@ -117,16 +116,16 @@ class InflectorTest < Test::Unit::TestCase
     "product"                => "product",
     "special_guest"          => "specialGuest",
     "application_controller" => "applicationController",
-    "area51_controller"      => "area51Controller"     
+    "area51_controller"      => "area51Controller"
   }
-  
+
   CamelToUnderscoreWithoutReverse = {
     "HTMLTidy"              => "html_tidy",
     "HTMLTidyGenerator"     => "html_tidy_generator",
     "FreeBSD"               => "free_bsd",
     "HTML"                  => "html",
   }
-  
+
   CamelWithModuleToUnderscoreWithSlash = {
     "Admin::Product" => "admin/product",
     "Users::Commission::Department" => "users/commission/department",
@@ -142,12 +141,12 @@ class InflectorTest < Test::Unit::TestCase
     "Person" => "personid",
     "MyApplication::Billing::Account" => "accountid"
   }
-  
+
   ClassNameToTableName = {
     "PrimarySpokesman" => "primary_spokesmen",
     "NodeChild"        => "node_children"
   }
-  
+
   UnderscoreToHuman = {
     "employee_salary" => "Employee salary",
     "employee_id"     => "Employee",
@@ -191,16 +190,27 @@ class InflectorTest < Test::Unit::TestCase
     "103" => "103rd",
     "104" => "104th",
     "110" => "110th",
+    "111" => "111th",
+    "112" => "112th",
+    "113" => "113th",
     "1000" => "1000th",
     "1001" => "1001st"
   }
-  
+
   UnderscoresToDashes = {
     "street"                => "street",
     "street_address"        => "street-address",
     "person_street_address" => "person-street-address"
   }
 
+  Irregularities = {
+    'person' => 'people',
+    'man'    => 'men',
+    'child'  => 'children',
+    'sex'    => 'sexes',
+    'move'   => 'moves',
+  }
+
   def test_pluralize_plurals
     assert_equal "plurals", Inflector.pluralize("plurals")
     assert_equal "Plurals", Inflector.pluralize("Plurals")
@@ -220,9 +230,9 @@ class InflectorTest < Test::Unit::TestCase
     end
   end
 
-  MixtureToTitleCase.each do |before, title_cased|
-    define_method 'test_titlecase' do
-      assert_equal(title_cased, Inflector.titleize(before))
+  MixtureToTitleCase.each do |before, titleized|
+    define_method "test_titleize_#{before}" do
+      assert_equal(titleized, Inflector.titleize(before))
     end
   end
 
@@ -246,7 +256,7 @@ class InflectorTest < Test::Unit::TestCase
       assert_equal(camel, Inflector.camelize(underscore))
     end
   end
-  
+
   def test_underscore_with_slashes
     CamelWithModuleToUnderscoreWithSlash.each do |camel, underscore|
       assert_equal(underscore, Inflector.underscore(camel))
@@ -278,22 +288,33 @@ class InflectorTest < Test::Unit::TestCase
       assert_equal(class_name, Inflector.classify(table_name))
     end
   end
-  
+
+  def test_classify_with_symbol
+    assert_nothing_raised do
+      assert_equal 'FooBar', Inflector.classify(:foo_bar)
+    end
+  end
+
+  def test_classify_with_leading_schema_name
+    assert_equal 'FooBar', Inflector.classify('schema.foo_bar')
+  end
+
   def test_humanize
     UnderscoreToHuman.each do |underscore, human|
       assert_equal(human, Inflector.humanize(underscore))
     end
   end
-  
+
   def test_constantize
-    assert_equal Ace::Base::Case, Inflector.constantize("Ace::Base::Case")
-    assert_equal Ace::Base::Case, Inflector.constantize("::Ace::Base::Case")
-    assert_equal InflectorTest, Inflector.constantize("InflectorTest")
-    assert_equal InflectorTest, Inflector.constantize("::InflectorTest")
+    assert_nothing_raised { assert_equal Ace::Base::Case, Inflector.constantize("Ace::Base::Case") }
+    assert_nothing_raised { assert_equal Ace::Base::Case, Inflector.constantize("::Ace::Base::Case") }
+    assert_nothing_raised { assert_equal InflectorTest, Inflector.constantize("InflectorTest") }
+    assert_nothing_raised { assert_equal InflectorTest, Inflector.constantize("::InflectorTest") }
     assert_raises(NameError) { Inflector.constantize("UnknownClass") }
     assert_raises(NameError) { Inflector.constantize("An invalid string") }
+    assert_raises(NameError) { Inflector.constantize("InvalidClass\n") }
   end
-  
+
   def test_constantize_doesnt_look_in_parent
     assert_raises(NameError) { Inflector.constantize("Ace::Base::InflectorTest") }
   end
@@ -321,4 +342,63 @@ class InflectorTest < Test::Unit::TestCase
       assert_equal(lower_camel, Inflector.camelize(underscored, false))
     end
   end
+
+  Irregularities.each do |irregularity|
+    singular, plural = *irregularity
+    Inflector.inflections do |inflect|
+      define_method("test_irregularity_between_#{singular}_and_#{plural}") do
+        inflect.irregular(singular, plural)
+        assert_equal singular, Inflector.singularize(plural)
+        assert_equal plural, Inflector.pluralize(singular)
+      end
+    end
+  end
+
+  [ :all, [] ].each do |scope|
+    Inflector.inflections do |inflect|
+      define_method("test_clear_inflections_with_#{scope.kind_of?(Array) ? "no_arguments" : scope}") do
+        # save all the inflections
+        singulars, plurals, uncountables = inflect.singulars, inflect.plurals, inflect.uncountables
+
+        # clear all the inflections
+        inflect.clear(*scope)
+
+        assert_equal [], inflect.singulars
+        assert_equal [], inflect.plurals
+        assert_equal [], inflect.uncountables
+
+        # restore all the inflections
+        singulars.reverse.each { |singular| inflect.singular(*singular) }
+        plurals.reverse.each   { |plural|   inflect.plural(*plural) }
+        inflect.uncountable(uncountables)
+
+        assert_equal singulars, inflect.singulars
+        assert_equal plurals, inflect.plurals
+        assert_equal uncountables, inflect.uncountables
+      end
+    end
+  end
+
+  { :singulars => :singular, :plurals => :plural, :uncountables => :uncountable }.each do |scope, method|
+    Inflector.inflections do |inflect|
+      define_method("test_clear_inflections_with_#{scope}") do
+        # save the inflections
+        values = inflect.send(scope)
+
+        # clear the inflections
+        inflect.clear(scope)
+
+        assert_equal [], inflect.send(scope)
+
+        # restore the inflections
+        if scope == :uncountables
+          inflect.send(method, values)
+        else
+          values.reverse.each { |value| inflect.send(method, *value) }
+        end
+
+        assert_equal values, inflect.send(scope)
+      end
+    end
+  end
 end
